pub fn ModalClose(props: ModalCloseProps) -> ElementExpand description
Div to close the content modal, by default it is a cross located at the top left corner of the modal If you provide a children, it will be used instead of the default cross and no internal styling will be provided